@@ -3,7 +3,11 @@
 
 
 resample = function (sound, newfs, oldfs, precision = 50, filterorder = 200, synthfilter = FALSE){
-  soundout = 0
+  soundout = 0; tsout = 0;
+  if (class(sound) == "ts"){
+    fs = frequency(sound)
+    tsout = 1
+  } 
   if (class(sound) == "sound") {
     soundout = 1
     oldsound = sound
@@ -25,10 +29,11 @@ resample = function (sound, newfs, oldfs, precision = 50, filterorder = 200, syn
     y = y + sound[nearest+precision+i] * sinc(offset - i, normalized = TRUE)
   
   if (ratio < 1 & !synthfilter) y = FIRfilter (y, to = oldfs/2, fs = newfs, order = filterorder)
-  if (ratio < 1 & synthfilter) y = synthfilter
+  if (ratio < 1 & synthfilter) y = synthfilter (y, band = c(0,oldfs/2), fs = newfs)
   
   sound = y / (max(y) * 1.05) 
   if (soundout == 1)  sound = makesound (sound, filename = oldsound$filename, fs = newfs)
+  if (tsout == 1)  sound = ts (sound, frequency = newfs, start = 0)
   return (sound)   
 }
 
