@@ -3,7 +3,11 @@
 
 
 synthfilter = function (sound, band = c(0,fs/4), fs = 1, verify = FALSE){
-  soundout = 0
+  soundout = 0; tsout = 0;	
+  if (class(sound) == "ts"){
+    fs = frequency(sound)
+    tsout = 1
+  }
   if (class(sound) == "sound") {
     soundout = 1
     fs = sound$fs
@@ -29,6 +33,8 @@ synthfilter = function (sound, band = c(0,fs/4), fs = 1, verify = FALSE){
   }
   output = output/sd(output) * sdin
   if (soundout == 1)  output = makesound (output, filename = oldsound$filename, fs = fs)
+  if (tsout == 1) output = ts (output, frequency = fs, start = 0)
+ 
   invisible (output)
 }
 
